Module blaxel.core.client.models.sandbox_metrics
================================================

Classes
-------

`SandboxMetrics(memory: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, percent: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, timestamp: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, value: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>)`
:   Enhanced sandbox metrics with memory, value, and percent data
    
    Attributes:
        memory (Union[Unset, float]): Memory limit in bytes (from query A)
        percent (Union[Unset, float]): Memory usage percentage (from formula F1)
        timestamp (Union[Unset, str]): Metric timestamp
        value (Union[Unset, float]): Memory usage in bytes (from query B)
    
    Method generated by attrs for class SandboxMetrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `memory: blaxel.core.client.types.Unset | float`
    :

    `percent: blaxel.core.client.types.Unset | float`
    :

    `timestamp: blaxel.core.client.types.Unset | str`
    :

    `value: blaxel.core.client.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :